The bblocks package
===================

|pypi| |python| |Documentation| |codecov|


**bblocks** is a python package with tools to download and analyse
development data. These tools are meant to be the *building blocks* of
further analysis.

**bblocks** is currently in active development. Functionality and APIs
are very likely to change. We welcome feedback, feature requests, and
collaboration. We hope that this will be a valuable resource for
organisations working with sustainable development data.

-  Documentation: https://bblocks.readthedocs.io/
-  GitHub: https://github.com/ONECampaign/bblocks
-  PyPI: https://pypi.org/project/bblocks/
-  Free software: MIT

Installation
------------

bblocks can be installed from PyPI: from the command line:

.. code-block:: python

   pip install bblocks

Alternatively, the source code is available on
`GitHub <https://github.com/ONECampaign/bblocks>`__.

Basic usage
-----------

bblocks is in active development. Check back regularly for new features.
We will be adding example jupyter notebooks for some of the main
features. Be sure to check the issues or projects section to learn more
about the features that we are planning to add.

Questions?
----------

Please feel free to reach out via GitHub or at data at one.org

.. |pypi| image:: https://img.shields.io/pypi/v/bblocks.svg
   :target: https://pypi.org/project/bblocks/
.. |python| image:: https://img.shields.io/pypi/pyversions/bblocks.svg
   :target: https://pypi.org/project/bblocks/
.. |codecov| image:: https://codecov.io/gh/ONECampaign/bblocks/branch/main/graph/badge.svg?token=YN8S1719NH
   :target: https://codecov.io/gh/ONECampaign/bblocks
.. |Documentation| image:: https://readthedocs.org/projects/bblocks/badge/?version=latest
   :target: https://bblocks.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
